<?php

namespace Drupal\tuition_calculator\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\HtmlCommand;
use Symfony\Component\HttpFoundation\ResponseHeaderBag;
use Symfony\Component\HttpFoundation\BinaryFileResponse;
use Drupal\Core\Datetime\Entity\DateFormat;

/**
 * Configure site information settings for this site.
 */
class TuitionCalculatorBlockFormCalc extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'tuition_calculator_form_calc';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['tuition_calculator.settings'];
  }

  /**
   * Creates the form and defines all of the classes for the divs.
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $tuition_calculator_config = $this->config('tuition_calculator.settings');
    $title = strtolower($tuition_calculator_config->get('tuition_calculator_calc_title'));
    $intro_text = $tuition_calculator_config->get('tuition_calculator_calc_intro');
    $default_tuition = '$' . number_format($tuition_calculator_config->get('tuition_calculator_tuition'));
    $default_institution = $tuition_calculator_config->get('tuition_calculator_school_short');
    $disclaimer = $tuition_calculator_config->get('tuition_calculator_calc_disc');

    $form['#prefix'] = '<div class="container col-calculator flexrow">';
    $form['#suffix'] = '</div>';
    $form['#attached']['library'] = 'tuition_calculator/tuition-calculator';

    if (!empty($title)) {
      $form['title'] = [
        '#suffix' => '<h3 class="title-row col-md-12">' . $title . '</h3>',
      ];
    }

    if (!empty($intro_text)) {
      $form['intro_text'] = [
        '#suffix' => '<div class="intro-row col-md-12">' . $intro_text . '</div>',
      ];
    }

    $form['institution_name'] = [
      '#prefix' => '<div class="tuition-calc-form-container"><div class="tuition-header col-md-12"><div class="calculator col-md-2 hidden-xs hidden-sm row-title">' . $tuition_calculator_config->get('tuition_calculator_calc_label_school'),
      '#suffix' => '</div>',
    ];

    $form['institution_0'] = [
      '#type' => 'textfield',
      '#default_value' => $default_institution,
      '#attributes' => ['disabled' => 'TRUE'],
      '#prefix' => '<div class="calculator col-md-2 hidden-xs hidden-sm col-first">',
      '#suffix' => '</div></div>',
    ];

    $form['tuition_title'] = [
      '#prefix' => '<div class="tuition-row-1 col-md-12"><div class="calculator col-md-2 hidden-xs hidden-sm row-title">' . $tuition_calculator_config->get('tuition_calculator_calc_label_tuition'),
      '#suffix' => '</div>',
    ];

    $form['tuition_0'] = [
      '#type' => 'textfield',
      '#default_value' => $default_tuition,
      '#attributes' => ['disabled' => 'TRUE'],
      '#prefix' => '<div class="calculator col-md-2 hidden-xs hidden-sm col-first">',
      '#suffix' => '</div></div>',
    ];

    $form['grants_title'] = [
      '#prefix' => '<div class="tuition-row-2 col-md-12"><div class="calculator col-md-2 hidden-xs hidden-sm row-title">' . $tuition_calculator_config->get('tuition_calculator_calc_label_row_3'),
      '#suffix' => '</div>',
    ];

    $form['grants_0'] = [
      '#type' => 'textfield',
      '#attributes' => ['placeholder' => '$0,000'],
      '#prefix' => '<div class="calculator col-md-2 hidden-xs hidden-sm col-first">',
      '#suffix' => '</div></div>',
    ];

    $form['scholarships_title'] = [
      '#prefix' => '<div class="tuition-row-3 col-md-12"><div class="calculator col-md-2 hidden-xs hidden-sm row-title">' . $tuition_calculator_config->get('tuition_calculator_calc_label_row_4'),
      '#suffix' => '</div>',
    ];

    $form['scholarships_0'] = [
      '#type' => 'textfield',
      '#attributes' => ['placeholder' => '$0,000'],
      '#prefix' => '<div class="calculator col-md-2 hidden-xs hidden-sm col-first">',
      '#suffix' => '</div></div>',
    ];

    $form['loans_title'] = [
      '#prefix' => '<div class="tuition-row-4 col-md-12"><div class="calculator col-md-2 hidden-xs hidden-sm row-title">' . $tuition_calculator_config->get('tuition_calculator_calc_label_row_5'),
      '#suffix' => '</div>',
    ];

    $form['loans_0'] = [
      '#type' => 'textfield',
      '#attributes' => ['placeholder' => '$0,000'],
      '#prefix' => '<div class="calculator col-md-2 hidden-xs hidden-sm col-first">',
      '#suffix' => '</div></div>',
    ];

    $form['total_title'] = [
      '#suffix' => '<div class="tuition-row-5 col-md-12"><div class="calculator col-md-2 hidden-xs hidden-sm row-title"><strong>Total</strong></div>',
    ];

    $form['total_0'] = [
      '#prefix' => '<div class="calculator col-md-2 hidden-xs hidden-sm col-total col-first"><div class="total-0">$0',
      '#suffix' => '</div></div></div>',
    ];

    $form['buttons_title'] = [
      '#suffix' => '<div class="tuition-row-6 col-md-12 col-buttons"><div class="calculator col-md-2 hidden-xs hidden-sm row-title"></div>',
    ];

    $form['buttons_1'] = [
      '#prefix' => '<div class="calculator col-md-4 hidden-xs hidden-sm col-buttons col-first">',
      '#suffix' => '</div>',
    ];

    $form['buttons_2'] = [
      '#prefix' => '<div class="calculator col-md-12 hidden-xs hidden-sm disclaimer-row">',
      '#suffix' => '' . $disclaimer . '</div>',
    ];

    $form['buttons_3'] = [
      '#prefix' => '<div class="calculator col-md-4 hidden-xs hidden-sm col-buttons col-third">',
      '#suffix' => '</div><div class="tuition-row-6 col-md-12 col-buttons">',
    ];

    // Uncomment if you would like to add a submission button to this form
    $form['actions']['#type'] = 'actions';
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Calculate'),
      '#button_type' => 'primary',
      '#prefix' => '<div class="calculator col-md-12 hidden-xs hidden-sm col-buttons col-fourth"><div class="calculate-button">',
      '#suffix' => '</div><div class="download-pdf"></div></div>',
      '#ajax' => [
        'callback' => '::calculateAjax',
        'event' => 'click',
        'progress' => [
          'type' => 'throbber',
        ],
      ],
    ];

    $form['buttons_suffix'] = [
      '#suffix' => '</div></div></div>',
    ];

    return $form;
  }

  /**
   * Ajax callback that processes the calculation.
   */
  public function calculateAjax(array &$form, FormStateInterface $form_state) {

    $response = new AjaxResponse();

    // Remove all monetary punctuation.
    $strip = ['$', ',', '.'];

    $institution_0 = $form_state->getValue('institution_0');
    $tuition_0 = (int) str_replace($strip, '', $form_state->getValue('tuition_0'));
    $grants_0 = (int) str_replace($strip, '', $form_state->getValue('grants_0'));
    $scholarships_0 = (int) str_replace($strip, '', $form_state->getValue('scholarships_0'));
    $loans_0 = (int) str_replace($strip, '', $form_state->getValue('loans_0'));
    $total_0 = (int) str_replace($strip, '', $form_state->getValue('total_0'));

    $form_state->setValue('tuition_0', $tuition_0);
    $form_state->setValue('institution_0', $institution_0);
    $form_state->setValue('grants_0', $grants_0);
    $form_state->setValue('scholarships_0', $scholarships_0);
    $form_state->setValue('loans_0', $loans_0);
    $form_state->setValue('total_0', $total_0);

    // Perform the calculation and pass it to the calculate message div.

    if ($grants_0 !== 0 && $scholarships_0 !== 0 && $loans_0 !== 0) {
      $tuition_calc_0 = ((($tuition_0 - $grants_0) - $scholarships_0) - $loans_0);
    }
    elseif ($grants_0 !== 0 && $scholarships_0 !== 0) {
      $tuition_calc_0 = (($tuition_0 - $grants_0) - $scholarships_0);
    }
    elseif ($grants_0 !== 0 && $loans_0 !== 0) {
      $tuition_calc_0 = (($tuition_0 - $grants_0) - $loans_0);
    }
    elseif ($scholarships_0 !== 0 && $loans_0 !== 0) {
      $tuition_calc_0 = (($tuition_0 - $scholarships_0) - $loans_0);
    }
    elseif ($grants_0 !== 0) {
      $tuition_calc_0 = ($tuition_0 - $grants_0);
    }
    elseif ($scholarships_0 !== 0) {
      $tuition_calc_0 = ($tuition_0 - $scholarships_0);
    }
    elseif ($loans_0 !== 0) {
      $tuition_calc_0 = ($tuition_0 - $loans_0);
    }
    elseif ($tuition_0 !== 0) {
      $tuition_calc_0 = ($tuition_0);
    }
    else {
      $tuition_calc_0 = 1;
    }

    $tuition_comma_0 = number_format($tuition_calc_0);
    $tuition_view_0 = '$' . $tuition_comma_0;

    $form_state->setValue('total_0', $tuition_view_0);
    $response->addCommand(new HtmlCommand('.total-0', $tuition_view_0));

    $tuition_calc_data = [
      [
        'school' => $institution_0,
        'tuition' => $tuition_0,
        'grants' => $grants_0,
        'scholarships' => $scholarships_0,
        'loans' => $loans_0,
        'total' => $tuition_view_0,
      ],
    ];

    $form_state->setValue('tuition_calc_data', $tuition_calc_data);

    $tuition_calculator_config = $this->config('tuition_calculator.settings');
    $school_name = strtolower($tuition_calculator_config->get('tuition_calculator_school_name'));
    $title = strtolower($tuition_calculator_config->get('tuition_calculator_calc_title'));
    $intro_text = strtolower($tuition_calculator_config->get('tuition_calculator_calc_intro'));
    $disclaimer = strtolower($tuition_calculator_config->get('tuition_calculator_calc_disc'));
    $enablepdf = strtolower($tuition_calculator_config->get('tuition_calculator_enable_pdf'));
    $pdf_date_now = date('U');
    $pdf_date_string = \Drupal::service('date.formatter')
      ->format($pdf_date_now, 'custom', 'Y-m-d-H-i');
    $date = date('Y-m-d H:i:s');
    $filename = 'pdf_tuition-' . $pdf_date_string;
    $filespath = \Drupal::service('file_system')
        ->realpath(\Drupal::config('system.file')
            ->get('default_scheme') . "://") . '/';
    $filesdir = substr($filespath, strpos($filespath, "/sites/"));
    $pathdir = $filesdir . 'pdf';
    $path = $pathdir . '/' . $filename;

    if ($enablepdf == 1) {
      $download_pdf = '<a href="' . $path . '.pdf" class="secondary-button" target="_blank">Download PDF</a>';
      $response->addCommand(new HtmlCommand('.download-pdf', $download_pdf));
    }

    $html = '
<div id="pdf-export">
<div class="pdf-header">
<h2>' . $school_name . '</h2>
</div>
<div class ="pdf-intro">
<div class ="pdf-title"><h1>' . $title . '</h1></div>
<div class ="pdf-intro">' . $intro_text . '</div>
</div>
<div class ="pdf-body">
<table class="bpmTopicC"><thead>
<tr class="headerrow"><th>' . $tuition_calculator_config->get('tuition_calculator_calc_label_school') . '</th>
<td>' . $institution_0 . '</td>
</tr>
</thead><tbody>
<tr class="oddrow"><th>' . $tuition_calculator_config->get('tuition_calculator_calc_label_tuition') . '</th>
<td>' . $tuition_0 . '</td>
</tr>
<tr class="evenrow"><th>' . $tuition_calculator_config->get('tuition_calculator_calc_label_row_3') . '</th>
<td>' . $grants_0 . '</td>
</tr>
<tr class="oddrow"><th>' . $tuition_calculator_config->get('tuition_calculator_calc_label_row_4') . '</th>
<td>' . $scholarships_0 . '</td>
</tr>
<tr class="evenrow"><th>' . $tuition_calculator_config->get('tuition_calculator_calc_label_row_5') . '</th>
<td>' . $loans_0 . '</td>
</tr>
<tr class="oddrow"><th>Total</th>
<td>' . $tuition_view_0 . '</td>
</tr>
<tr class="evenrow"><th></th>
<td></td>
</tr>
</tbody></table>
<div class="pdf-footer">
<div class="pdf-disclaimer">' . $disclaimer . '</div>
</div>
</div>
</div>
';
    $settings = [];
    $dateFormatValidate = DateFormat::load('tuition_calculator_file');
    $dateFormatID = $dateFormatValidate->id();
    $pdf_css_file_path = drupal_get_path('module', 'tuition_calculator') . '/css/tuition-calculator-pdf.css';

    if ($dateFormatID == 'tuition_calculator_file') {
      $pdf_date_format = 'tuition_calculator_file';
    }
    else {
      $pdf_date_format = 'html_date';
    }

    if (file_exists($pdf_css_file_path)) {
      $pdf_css_file = $pdf_css_file_path;
    }
    else {
      $pdf_css_file = 'modules/contrib/tuition_calculator/css/tuition-calculator-pdf.css';
    }

    $settings['pdf_filename'] = 'pdf_tuition-[current-date:' . $pdf_date_format . ']';
    $settings['pdf_filepath'] = "pdf";
    $settings['pdf_save_option'] = "2";
    $settings['pdf_css_file'] = $pdf_css_file;

    /** @var \Drupal\pdf_using_mpdf\ConvertToPdfInterface $pdf */
    $pdfService = \Drupal::service('pdf_using_mpdf.conversion');
    $pdfService->convert($html, $settings);

    return $response;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    // Remove all monetary punctuation.
    $strip = ['$', ',', '.'];

    $institution_0 = $form_state->getValue('institution_0');
    $tuition_0 = (int) str_replace($strip, '', $form_state->getValue('tuition_0'));
    $grants_0 = (int) str_replace($strip, '', $form_state->getValue('grants_0'));
    $scholarships_0 = (int) str_replace($strip, '', $form_state->getValue('scholarships_0'));
    $loans_0 = (int) str_replace($strip, '', $form_state->getValue('loans_0'));
    $total_0 = (int) str_replace($strip, '', $form_state->getValue('total_0'));

    $form_state->setValue('tuition_0', $tuition_0);
    $form_state->setValue('institution_0', $institution_0);
    $form_state->setValue('grants_0', $grants_0);
    $form_state->setValue('scholarships_0', $scholarships_0);
    $form_state->setValue('loans_0', $loans_0);
    $form_state->setValue('total_0', $total_0);

    // Perform the calculation and pass it to the calculate message div.

    if ($grants_0 !== 0 && $scholarships_0 !== 0 && $loans_0 !== 0) {
      $tuition_calc_0 = ((($tuition_0 - $grants_0) - $scholarships_0) - $loans_0);
    }
    elseif ($grants_0 !== 0 && $scholarships_0 !== 0) {
      $tuition_calc_0 = (($tuition_0 - $grants_0) - $scholarships_0);
    }
    elseif ($grants_0 !== 0 && $loans_0 !== 0) {
      $tuition_calc_0 = (($tuition_0 - $grants_0) - $loans_0);
    }
    elseif ($scholarships_0 !== 0 && $loans_0 !== 0) {
      $tuition_calc_0 = (($tuition_0 - $scholarships_0) - $loans_0);
    }
    elseif ($grants_0 !== 0) {
      $tuition_calc_0 = ($tuition_0 - $grants_0);
    }
    elseif ($scholarships_0 !== 0) {
      $tuition_calc_0 = ($tuition_0 - $scholarships_0);
    }
    elseif ($loans_0 !== 0) {
      $tuition_calc_0 = ($tuition_0 - $loans_0);
    }
    elseif ($tuition_0 !== 0) {
      $tuition_calc_0 = ($tuition_0);
    }
    else {
      $tuition_calc_0 = 0;
    }

    $tuition_comma_0 = number_format($tuition_calc_0);
    $tuition_view_0 = '$' . $tuition_comma_0;

    $tuition_calc_data = [
      [
        'school' => $institution_0,
        'tuition' => $tuition_0,
        'grants' => $grants_0,
        'scholarships' => $scholarships_0,
        'loans' => $loans_0,
        'total' => $tuition_view_0,
      ],
    ];

    $form_state->setValue('tuition_calc_data', $tuition_calc_data);

    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   *
   * This is an empty submit function that can be filled in as needed.
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    $data = $form_state->getValue('tuition_calc_data');

    if (isset($data)) {
      $csv_date_now = date('U');
      $csv_date_string = \Drupal::service('date.formatter')
        ->format($csv_date_now, 'custom', 'Y-m-d-H-i');
      $filename = 'pdf_tuition-' . $csv_date_string . '.csv';
      $path = \Drupal::config('system.file')->get('default_scheme') . '://pdf/';
      $delimiter = ',';
      $file = fopen($path . $filename, 'w');
      $line = ['school', 'tuition', 'grants', 'scholarships', 'loans', 'total'];
      fputcsv($file, $line, $delimiter);
      foreach ($data as $item) {
        fputcsv($file, $item);
      }
      fclose($file);

      $response = new BinaryFileResponse($path . $filename);
      $response->setContentDisposition(
        ResponseHeaderBag::DISPOSITION_ATTACHMENT,
        $filename
      );
      $form_state->setResponse($response);
    }
  }

}
