<?php

namespace Drupal\tuition_calculator\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\HtmlCommand;
use Symfony\Component\HttpFoundation\ResponseHeaderBag;
use Symfony\Component\HttpFoundation\BinaryFileResponse;
use Drupal\Core\Datetime\Entity\DateFormat;

/**
 * Configure site information settings for this site.
 */
class TuitionCalculatorBlockFormComp extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'tuition_calculator_form_comp';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['tuition_calculator.settings'];
  }


  /**
   * Creates the form and defines all of the classes for the divs.
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    // Get settings for this form.
    $settings = $this->configFactory()
      ->getEditable('tuition_calculator.settings')
      ->get('tuition_calculator');

    $title = strtolower($settings['comp_title']);
    $intro_text = $settings['comp_intro'];
    $default_tuition = '$' . number_format($settings['tuition']);
    $default_institution = $settings['school_short'];
    $disclaimer = $settings['comp_disc'];

    $form['#prefix'] = '<div class="container col-calculator flexrow">';
    $form['#suffix'] = '</div>';
    $form['#attached']['library'] = 'tuition_calculator/tuition-calculator';

    if (!empty($title)) {
      $form['title'] = [
        '#suffix' => '<h3 class="title-row col-md-12">' . $title . '</h3>',
      ];
    }

    if (!empty($intro_text)) {
      $form['intro_text'] = [
        '#suffix' => '<div class="intro-row col-md-12">' . $intro_text . '</div>',
      ];
    }

    $form['institution_name'] = [
      '#prefix' => '<div class="tuition-calc-form-container"><div class="tuition-header col-md-12"><div class="calculator col-md-2 hidden-xs hidden-sm row-title">' . $settings['comp_label_school'],
      '#suffix' => '</div>',
    ];

    $form['institution_0'] = [
      '#type' => 'textfield',
      '#default_value' => $default_institution,
      '#attributes' => ['disabled' => 'TRUE'],
      '#prefix' => '<div class="calculator col-md-1 hidden-xs hidden-sm col-first">',
      '#suffix' => '</div>',
    ];

    $form['institution_1'] = [
      '#type' => 'textfield',
      '#default_value' => 'School 1',
      '#prefix' => '<div class="calculator col-md-1 hidden-xs hidden-sm">',
      '#suffix' => '</div>',
    ];

    $form['institution_2'] = [
      '#type' => 'textfield',
      '#default_value' => 'School 2',
      '#prefix' => '<div class="calculator col-md-1 hidden-xs hidden-sm">',
      '#suffix' => '</div>',
    ];

    $form['institution_3'] = [
      '#type' => 'textfield',
      '#default_value' => 'School 3',
      '#prefix' => '<div class="calculator col-md-1 hidden-xs hidden-sm">',
      '#suffix' => '</div></div>',
    ];

    $form['tuition_title'] = [
      '#prefix' => '<div class="tuition-row-1 col-md-12"><div class="calculator col-md-2 hidden-xs hidden-sm row-title">' . $settings['comp_label_tuition'],
      '#suffix' => '</div>',
    ];

    $form['tuition_0'] = [
      '#type' => 'textfield',
      '#default_value' => $default_tuition,
      '#attributes' => ['disabled' => 'TRUE'],
      '#prefix' => '<div class="calculator col-md-1 hidden-xs hidden-sm col-first">',
      '#suffix' => '</div>',
    ];

    $form['tuition_1'] = [
      '#type' => 'textfield',
      '#attributes' => ['placeholder' => '$0,000'],
      '#prefix' => '<div class="calculator col-md-1 hidden-xs hidden-sm col-second">',
      '#suffix' => '</div>',
    ];

    $form['tuition_2'] = [
      '#type' => 'textfield',
      '#attributes' => ['placeholder' => '$0,000'],
      '#prefix' => '<div class="calculator col-md-1 hidden-xs hidden-sm col-third">',
      '#suffix' => '</div>',
    ];

    $form['tuition_3'] = [
      '#type' => 'textfield',
      '#attributes' => ['placeholder' => '$0,000'],
      '#prefix' => '<div class="calculator col-md-1 hidden-xs hidden-sm col-fourth">',
      '#suffix' => '</div></div>',
    ];

    $form['grants_title'] = [
      '#prefix' => '<div class="tuition-row-2 col-md-12"><div class="calculator col-md-2 hidden-xs hidden-sm row-title">' . $settings['comp_label_row_3'],
      '#suffix' => '</div>',
    ];

    $form['grants_0'] = [
      '#type' => 'textfield',
      '#attributes' => ['placeholder' => '$0,000'],
      '#prefix' => '<div class="calculator col-md-1 hidden-xs hidden-sm col-first">',
      '#suffix' => '</div>',
    ];

    $form['grants_1'] = [
      '#type' => 'textfield',
      '#attributes' => ['placeholder' => '$0,000'],
      '#prefix' => '<div class="calculator col-md-1 hidden-xs hidden-sm">',
      '#suffix' => '</div>',
    ];

    $form['grants_2'] = [
      '#type' => 'textfield',
      '#attributes' => ['placeholder' => '$0,000'],
      '#prefix' => '<div class="calculator col-md-1 hidden-xs hidden-sm">',
      '#suffix' => '</div>',
    ];

    $form['grants_3'] = [
      '#type' => 'textfield',
      '#attributes' => ['placeholder' => '$0,000'],
      '#prefix' => '<div class="calculator col-md-1 hidden-xs hidden-sm">',
      '#suffix' => '</div></div>',
    ];

    $form['scholarships_title'] = [
      '#prefix' => '<div class="tuition-row-3 col-md-12"><div class="calculator col-md-2 hidden-xs hidden-sm row-title">' . $settings['comp_label_row_4'],
      '#suffix' => '</div>',
    ];

    $form['scholarships_0'] = [
      '#type' => 'textfield',
      '#attributes' => ['placeholder' => '$0,000'],
      '#prefix' => '<div class="calculator col-md-1 hidden-xs hidden-sm col-first">',
      '#suffix' => '</div>',
    ];

    $form['scholarships_1'] = [
      '#type' => 'textfield',
      '#attributes' => ['placeholder' => '$0,000'],
      '#prefix' => '<div class="calculator col-md-1 hidden-xs hidden-sm">',
      '#suffix' => '</div>',
    ];

    $form['scholarships_2'] = [
      '#type' => 'textfield',
      '#attributes' => ['placeholder' => '$0,000'],
      '#prefix' => '<div class="calculator col-md-1 hidden-xs hidden-sm">',
      '#suffix' => '</div>',
    ];

    $form['scholarships_3'] = [
      '#type' => 'textfield',
      '#attributes' => ['placeholder' => '$0,000'],
      '#prefix' => '<div class="calculator col-md-1 hidden-xs hidden-sm">',
      '#suffix' => '</div></div>',
    ];

    $form['loans_title'] = [
      '#prefix' => '<div class="tuition-row-4 col-md-12"><div class="calculator col-md-2 hidden-xs hidden-sm row-title">' . $settings['comp_label_row_5'],
      '#suffix' => '</div>',
    ];

    $form['loans_0'] = [
      '#type' => 'textfield',
      '#attributes' => ['placeholder' => '$0,000'],
      '#prefix' => '<div class="calculator col-md-1 hidden-xs hidden-sm col-first">',
      '#suffix' => '</div>',
    ];

    $form['loans_1'] = [
      '#type' => 'textfield',
      '#attributes' => ['placeholder' => '$0,000'],
      '#prefix' => '<div class="calculator col-md-1 hidden-xs hidden-sm">',
      '#suffix' => '</div>',
    ];

    $form['loans_2'] = [
      '#type' => 'textfield',
      '#attributes' => ['placeholder' => '$0,000'],
      '#prefix' => '<div class="calculator col-md-1 hidden-xs hidden-sm">',
      '#suffix' => '</div>',
    ];

    $form['loans_3'] = [
      '#type' => 'textfield',
      '#attributes' => ['placeholder' => '$0,000'],
      '#prefix' => '<div class="calculator col-md-1 hidden-xs hidden-sm">',
      '#suffix' => '</div></div>',
    ];

    $form['total_title'] = [
      '#suffix' => '<div class="tuition-row-5 col-md-12"><div class="calculator col-md-2 hidden-xs hidden-sm row-title"><strong>Total</strong></div>',
    ];

    $form['total_0'] = [
      '#prefix' => '<div class="calculator col-md-1 hidden-xs hidden-sm col-total col-first"><div class="total-0">$0',
      '#suffix' => '</div></div>',
    ];

    $form['total_1'] = [
      '#prefix' => '<div class="calculator col-md-1 hidden-xs hidden-sm col-total"><div class="total-1">$0',
      '#suffix' => '</div></div>',
    ];

    $form['total_2'] = [
      '#prefix' => '<div class="calculator col-md-1 hidden-xs hidden-sm col-total"><div class="total-2">$0',
      '#suffix' => '</div></div>',
    ];

    $form['total_3'] = [
      '#prefix' => '<div class="calculator col-md-1 hidden-xs hidden-sm col-total"><div class="total-3">$0',
      '#suffix' => '</div></div></div>',
    ];

    $form['buttons_title'] = [
      '#suffix' => '<div class="tuition-row-6 col-md-12 col-buttons"><div class="calculator col-md-2 hidden-xs hidden-sm row-title"></div>',
    ];

    $form['buttons_1'] = [
      '#prefix' => '<div class="calculator col-md-4 hidden-xs hidden-sm col-buttons col-first">',
      '#suffix' => '</div>',
    ];

    $form['buttons_2'] = [
      '#prefix' => '<div class="calculator col-md-12 hidden-xs hidden-sm disclaimer-row">',
      '#suffix' => '' . $disclaimer . '</div>',
    ];

    $form['buttons_3'] = [
      '#prefix' => '<div class="calculator col-md-4 hidden-xs hidden-sm col-buttons col-third">',
      '#suffix' => '</div><div class="tuition-row-6 col-md-12 col-buttons">',
    ];

    // Uncomment if you would like to add a submission button to this form
    $form['actions']['#type'] = 'actions';
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Calculate'),
      '#button_type' => 'primary',
      '#prefix' => '<div class="calculator col-md-12 hidden-xs hidden-sm col-buttons col-fourth"><div class="calculate-button">',
      '#suffix' => '</div><div class="download-pdf"></div></div>',
      '#ajax' => [
        'callback' => '::calculateAjax',
        'event' => 'click',
        'progress' => [
          'type' => 'throbber',
        ],
      ],
    ];

    $form['buttons_suffix'] = [
      '#suffix' => '</div></div></div>',
    ];

    return $form;
  }

  /**
   * Ajax callback that processes the calculation.
   */
  public function calculateAjax(array &$form, FormStateInterface $form_state) {

    $response = new AjaxResponse();

    // Remove all monetary punctuation.
    $strip = ['$', ',', '.'];

    $institution_0 = $form_state->getValue('institution_0');
    $tuition_0 = (int) str_replace($strip, '', $form_state->getValue('tuition_0'));
    $grants_0 = (int) str_replace($strip, '', $form_state->getValue('grants_0'));
    $scholarships_0 = (int) str_replace($strip, '', $form_state->getValue('scholarships_0'));
    $loans_0 = (int) str_replace($strip, '', $form_state->getValue('loans_0'));
    $total_0 = (int) str_replace($strip, '', $form_state->getValue('total_0'));

    $form_state->setValue('tuition_0', $tuition_0);
    $form_state->setValue('institution_0', $institution_0);
    $form_state->setValue('grants_0', $grants_0);
    $form_state->setValue('scholarships_0', $scholarships_0);
    $form_state->setValue('loans_0', $loans_0);
    $form_state->setValue('total_0', $total_0);

    $tuition_1 = (int) str_replace($strip, '', $form_state->getValue('tuition_1'));
    $institution_1 = $form_state->getValue('institution_1');
    $grants_1 = (int) str_replace($strip, '', $form_state->getValue('grants_1'));
    $scholarships_1 = (int) str_replace($strip, '', $form_state->getValue('scholarships_1'));
    $loans_1 = (int) str_replace($strip, '', $form_state->getValue('loans_1'));
    $total_1 = (int) str_replace($strip, '', $form_state->getValue('total_1'));

    $form_state->setValue('tuition_1', $tuition_1);
    $form_state->setValue('institution_1', $institution_1);
    $form_state->setValue('grants_1', $grants_1);
    $form_state->setValue('scholarships_1', $scholarships_1);
    $form_state->setValue('loans_1', $loans_1);
    $form_state->setValue('total_1', $total_1);

    $tuition_2 = (int) str_replace($strip, '', $form_state->getValue('tuition_2'));
    $institution_2 = $form_state->getValue('institution_2');
    $grants_2 = (int) str_replace($strip, '', $form_state->getValue('grants_2'));
    $scholarships_2 = (int) str_replace($strip, '', $form_state->getValue('scholarships_2'));
    $loans_2 = (int) str_replace($strip, '', $form_state->getValue('loans_2'));
    $total_2 = (int) str_replace($strip, '', $form_state->getValue('total_2'));

    $form_state->setValue('tuition_2', $tuition_2);
    $form_state->setValue('institution_2', $institution_2);
    $form_state->setValue('grants_2', $grants_2);
    $form_state->setValue('scholarships_2', $scholarships_2);
    $form_state->setValue('loans_2', $loans_2);
    $form_state->setValue('total_2', $total_2);

    $tuition_3 = (int) str_replace($strip, '', $form_state->getValue('tuition_3'));
    $institution_3 = $form_state->getValue('institution_3');
    $grants_3 = (int) str_replace($strip, '', $form_state->getValue('grants_3'));
    $scholarships_3 = (int) str_replace($strip, '', $form_state->getValue('scholarships_3'));
    $loans_3 = (int) str_replace($strip, '', $form_state->getValue('loans_3'));
    $total_3 = (int) str_replace($strip, '', $form_state->getValue('total_3'));

    $form_state->setValue('tuition_3', $tuition_3);
    $form_state->setValue('institution_3', $institution_3);
    $form_state->setValue('grants_3', $grants_3);
    $form_state->setValue('scholarships_3', $scholarships_3);
    $form_state->setValue('loans_3', $loans_3);
    $form_state->setValue('total_3', $total_3);

    // Perform the calculation and pass it to the calculate message div.

    if ($grants_0 !== 0 && $scholarships_0 !== 0 && $loans_0 !== 0) {
      $tuition_calc_0 = ((($tuition_0 - $grants_0) - $scholarships_0) - $loans_0);
    }
    elseif ($grants_0 !== 0 && $scholarships_0 !== 0) {
      $tuition_calc_0 = (($tuition_0 - $grants_0) - $scholarships_0);
    }
    elseif ($grants_0 !== 0 && $loans_0 !== 0) {
      $tuition_calc_0 = (($tuition_0 - $grants_0) - $loans_0);
    }
    elseif ($scholarships_0 !== 0 && $loans_0 !== 0) {
      $tuition_calc_0 = (($tuition_0 - $scholarships_0) - $loans_0);
    }
    elseif ($grants_0 !== 0) {
      $tuition_calc_0 = ($tuition_0 - $grants_0);
    }
    elseif ($scholarships_0 !== 0) {
      $tuition_calc_0 = ($tuition_0 - $scholarships_0);
    }
    elseif ($loans_0 !== 0) {
      $tuition_calc_0 = ($tuition_0 - $loans_0);
    }
    elseif ($tuition_0 !== 0) {
      $tuition_calc_0 = ($tuition_0);
    }
    else {
      $tuition_calc_0 = 1;
    }

    if ($grants_1 !== 0 && $scholarships_1 !== 0 && $loans_1 !== 0) {
      $tuition_calc_1 = ((($tuition_1 - $grants_1) - $scholarships_1) - $loans_1);
    }
    elseif ($grants_1 !== 0 && $scholarships_1 !== 0) {
      $tuition_calc_1 = (($tuition_1 - $grants_1) - $scholarships_1);
    }
    elseif ($grants_1 !== 0 && $loans_1 !== 0) {
      $tuition_calc_1 = (($tuition_1 - $grants_1) - $loans_1);
    }
    elseif ($scholarships_1 !== 0 && $loans_1 !== 0) {
      $tuition_calc_1 = (($tuition_1 - $scholarships_1) - $loans_1);
    }
    elseif ($grants_1 !== 0) {
      $tuition_calc_1 = ($tuition_1 - $grants_1);
    }
    elseif ($scholarships_1 !== 0) {
      $tuition_calc_1 = ($tuition_1 - $scholarships_1);
    }
    elseif ($loans_1 !== 0) {
      $tuition_calc_1 = ($tuition_1 - $loans_1);
    }
    elseif ($tuition_1 !== 0) {
      $tuition_calc_1 = ($tuition_1);
    }
    else {
      $tuition_calc_1 = 0;
    }

    if ($grants_2 !== 0 && $scholarships_2 !== 0 && $loans_2 !== 0) {
      $tuition_calc_2 = ((($tuition_2 - $grants_2) - $scholarships_2) - $loans_2);
    }
    elseif ($grants_2 !== 0 && $scholarships_2 !== 0) {
      $tuition_calc_2 = (($tuition_2 - $grants_2) - $scholarships_2);
    }
    elseif ($grants_2 !== 0 && $loans_2 !== 0) {
      $tuition_calc_2 = (($tuition_2 - $grants_2) - $loans_2);
    }
    elseif ($scholarships_2 !== 0 && $loans_2 !== 0) {
      $tuition_calc_2 = (($tuition_2 - $scholarships_2) - $loans_2);
    }
    elseif ($grants_2 !== 0) {
      $tuition_calc_2 = ($tuition_2 - $grants_2);
    }
    elseif ($scholarships_2 !== 0) {
      $tuition_calc_2 = ($tuition_2 - $scholarships_2);
    }
    elseif ($loans_2 !== 0) {
      $tuition_calc_2 = ($tuition_2 - $loans_2);
    }
    elseif ($tuition_2 !== 0) {
      $tuition_calc_2 = ($tuition_2);
    }
    else {
      $tuition_calc_2 = 0;
    }

    if ($grants_3 !== 0 && $scholarships_3 !== 0 && $loans_3 !== 0) {
      $tuition_calc_3 = ((($tuition_3 - $grants_3) - $scholarships_3) - $loans_3);
    }
    elseif ($grants_3 !== 0 && $scholarships_3 !== 0) {
      $tuition_calc_3 = (($tuition_3 - $grants_3) - $scholarships_3);
    }
    elseif ($grants_3 !== 0 && $loans_3 !== 0) {
      $tuition_calc_3 = (($tuition_3 - $grants_3) - $loans_3);
    }
    elseif ($scholarships_3 !== 0 && $loans_3 !== 0) {
      $tuition_calc_3 = (($tuition_3 - $scholarships_3) - $loans_3);
    }
    elseif ($grants_3 !== 0) {
      $tuition_calc_3 = ($tuition_3 - $grants_3);
    }
    elseif ($scholarships_3 !== 0) {
      $tuition_calc_3 = ($tuition_3 - $scholarships_3);
    }
    elseif ($loans_3 !== 0) {
      $tuition_calc_3 = ($tuition_3 - $loans_3);
    }
    elseif ($tuition_3 !== 0) {
      $tuition_calc_3 = ($tuition_3);
    }
    else {
      $tuition_calc_3 = 0;
    }

    $tuition_comma_0 = number_format($tuition_calc_0);
    $tuition_view_0 = '$' . $tuition_comma_0;

    $form_state->setValue('total_0', $tuition_view_0);
    $response->addCommand(new HtmlCommand('.total-0', $tuition_view_0));

    $tuition_comma_1 = number_format($tuition_calc_1);
    $tuition_view_1 = '$' . $tuition_comma_1;

    $form_state->setValue('total_1', $tuition_view_1);
    $response->addCommand(new HtmlCommand('.total-1', $tuition_view_1));

    $tuition_comma_2 = number_format($tuition_calc_2);
    $tuition_view_2 = '$' . $tuition_comma_2;

    $form_state->setValue('total_2', $tuition_view_2);
    $response->addCommand(new HtmlCommand('.total-2', $tuition_view_2));

    $tuition_comma_3 = number_format($tuition_calc_3);
    $tuition_view_3 = '$' . $tuition_comma_3;

    $form_state->setValue('total_3', $tuition_view_3);
    $response->addCommand(new HtmlCommand('.total-3', $tuition_view_3));

    $tuition_calc_data = [
      [
        'school' => $institution_0,
        'tuition' => $tuition_0,
        'grants' => $grants_0,
        'scholarships' => $scholarships_0,
        'loans' => $loans_0,
        'total' => $tuition_view_0,
      ],
      [
        'school' => $institution_1,
        'tuition' => $tuition_1,
        'grants' => $grants_1,
        'scholarships' => $scholarships_1,
        'loans' => $loans_1,
        'total' => $tuition_view_1,
      ],
      [
        'school' => $institution_2,
        'tuition' => $tuition_2,
        'grants' => $grants_2,
        'scholarships' => $scholarships_2,
        'loans' => $loans_2,
        'total' => $tuition_view_2,
      ],
      [
        'school' => $institution_3,
        'tuition' => $tuition_3,
        'grants' => $grants_3,
        'scholarships' => $scholarships_3,
        'loans' => $loans_3,
        'total' => $tuition_view_3,
      ],
    ];

    $form_state->setValue('tuition_calc_data', $tuition_calc_data);

    // Get settings for this form.
    $settings = $this->configFactory()
      ->getEditable('tuition_calculator.settings')
      ->get('tuition_calculator');
    $school_name = strtolower($settings['school_name']);
    $school_short = strtolower($settings['school_short']);

    $title = strtolower($settings['comp_title']);
    $intro_text = strtolower($settings['comp_intro']);
    $disclaimer = strtolower($settings['comp_disc']);
    $total_0 = (int) str_replace($strip, '', $tuition_view_0);
    $pdf_date_now = date('U');
    $pdf_date_string = \Drupal::service('date.formatter')
      ->format($pdf_date_now, 'custom', 'Y-m-d-H');
    $filename = 'tuition-'. $school_short.'-' .$pdf_date_string .'-' . $total_0;
    $filespath = \Drupal::service('file_system')
        ->realpath(\Drupal::config('system.file')
            ->get('default_scheme') . "://") . '/';
    $filesdir = substr($filespath, strpos($filespath, "/sites/"));
    $pathdir = $filesdir . 'pdf';
    $path = $pathdir . '/' . $filename . '.pdf';
    if (file_exists($path)) {
      $path_to_file = $path;
    }
    else {
      $path_to_file = $path;
    }
      $download_pdf = '<a href="' . $path_to_file . '" class="secondary-button" target="_blank">Download PDF</a>';
      $response->addCommand(new HtmlCommand('.download-pdf', $download_pdf));

    $html = '
<div id="pdf-export">
<div class="pdf-header">
<h2>' . $school_name . '</h2>
</div>
<div class ="pdf-intro">
<div class ="pdf-title"><h1>' . $title . '</h1></div>
<div class ="pdf-intro">' . $intro_text . '</div>
</div>
<div class ="pdf-body">
<table class="bpmTopicC"><thead>
<tr class="headerrow"><th>' . $settings['comp_label_school'] . '</th>
<td>' . $institution_0 . '</td>
<td>' . $institution_1 . '</td>
<td>' . $institution_2 . '</td>
<td>' . $institution_3 . '</td>
</tr>
</thead><tbody>
<tr class="oddrow"><th>' . $settings['comp_label_tuition'] . '</th>
<td>' . $tuition_0 . '</td>
<td>' . $tuition_1 . '</td>
<td>' . $tuition_2 . '</td>
<td>' . $tuition_3 . '</td>
</tr>
<tr class="evenrow"><th>' . $settings['comp_label_row_3'] . '</th>
<td>' . $grants_0 . '</td>
<td>' . $grants_1 . '</td>
<td>' . $grants_2 . '</td>
<td>' . $grants_3 . '</td>
</tr>
<tr class="oddrow"><th>' . $settings['comp_label_row_4'] . '</th>
<td>' . $scholarships_0 . '</td>
<td>' . $scholarships_1 . '</td>
<td>' . $scholarships_2 . '</td>
<td>' . $scholarships_3 . '</td>
</tr>
<tr class="evenrow"><th>' . $settings['comp_label_row_5'] . '</th>
<td>' . $loans_0 . '</td>
<td>' . $loans_1 . '</td>
<td>' . $loans_2 . '</td>
<td>' . $loans_3 . '</td>
</tr>
<tr class="oddrow"><th>Total</th>
<td>' . $tuition_view_0 . '</td>
<td>' . $tuition_view_1 . '</td>
<td>' . $tuition_view_2 . '</td>
<td>' . $tuition_view_3 . '</td>
</tr>
<tr class="evenrow"><th></th>
<td></td>
</tr>
</tbody></table>
<div class="pdf-footer">
<div class="pdf-disclaimer">' . $disclaimer . '</div>
</div>
</div>
</div>
';
    $pdf_settings = [];
    $dateFormatValidate = DateFormat::load('tuition_calculator_file');
    $dateFormatID = $dateFormatValidate->id();
    $pdf_css_file_path = drupal_get_path('module', 'tuition_calculator') . '/css/tuition-calculator-pdf.css';

    if ($dateFormatID == 'tuition_calculator_file') {
      $pdf_date_format = 'tuition_calculator_file';
    }
    else {
      $pdf_date_format = 'html_date';
    }

    if (file_exists($pdf_css_file_path)) {
      $pdf_css_file = $pdf_css_file_path;
    }
    else {
      $pdf_css_file = 'modules/contrib/tuition_calculator/css/tuition-calculator-pdf.css';
    }
    $total_0 = (int) str_replace($strip, '', $tuition_view_0);
    $pdf_settings['pdf_filename'] = 'tuition-'. $school_short.'-' .$pdf_date_string .'-' . $total_0;
    $pdf_settings['pdf_filepath'] = "pdf";
    $pdf_settings['pdf_save_option'] = "2";
    $pdf_settings['pdf_css_file'] = $pdf_css_file;

    /** @var \Drupal\tuition_calculator\TuitionCalculatorPDFInterface $pdf */
    $pdfService = \Drupal::service('tuition_calculator.conversion');
    $pdfService->convert($html, $pdf_settings);

    return $response;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {

    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   *
   * This is an empty submit function that can be filled in as needed.
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    $data = $form_state->getValue('tuition_calc_data');
    $institution_0 = $form_state->getValue('institution_0');
    $total_0 = $form_state->getValue('total_0');

    if (isset($data)) {
      $csv_date_now = date('U');
      $csv_date_string = \Drupal::service('date.formatter')
        ->format($csv_date_now, 'custom', 'Y-m-d-H-');
      $filename = 'tuition-'. $institution_0.'-' .$csv_date_string .'-' . $total_0 . '.csv';
      $path = \Drupal::config('system.file')->get('default_scheme') . '://pdf/';
      $delimiter = ',';
      $file = fopen($path . $filename, 'w');
      $line = ['school', 'tuition', 'grants', 'scholarships', 'loans', 'total'];
      fputcsv($file, $line, $delimiter);
      foreach ($data as $item) {
        fputcsv($file, $item);
      }
      fclose($file);

      $response = new BinaryFileResponse($path . $filename);
      $response->setContentDisposition(
        ResponseHeaderBag::DISPOSITION_ATTACHMENT,
        $filename
      );
      $form_state->setResponse($response);
    }
  }

}
