<?php
namespace Drupal\tuition_calculator\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Link;
use Drupal\Core\Url;
use Drupal\file\Entity\File;

class TuitionCalculatorSettingsForm extends ConfigFormBase {
  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'tuition_calculator_config';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['tuition_calculator.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    // Get settings for this form.
    $settings = $this->configFactory()
      ->getEditable('tuition_calculator.settings')
      ->get('tuition_calculator');

    $stored_tuition = $settings['tuition'];
    if (!empty ($stored_tuition)) {
      $comma_tuition = '$' . number_format($stored_tuition);
    }
    else {
      $comma_tuition = '$' . number_format('200000');
    }
    $stored_institution = $settings['school_name'];
    if (!empty ($stored_institution)) {
      $institution = $stored_institution;
    }
    else {
      $institution = 'School';
    }

    $form['description'] = [
      '#type' => 'item',
      '#prefix' => '<p>',
      '#suffix' => '<p>',
      '#description' => $this->t('This form will allow you to define settings for the Tuition Calculator blocks and PDF download.'),
    ];
    // Setting for PDF header.
    $form['calc_top'] = array(
      '#type' => 'item',
      '#prefix' => '<hr>',
    );
    // Build form elements.
    $form['calc'] = [
      '#type' => 'vertical_tabs',
      '#attributes' => ['class' => ['tuition-calculator']],
      '#title' => t('CALCULATOR BLOCKS SETTINGS'),
      '#description' => t(''),
    ];

    // General tab.
    $form['school'] = [
      '#type' => 'details',
      '#title' => $this->t('School Information'),
      '#group' => 'calc',
    ];

    $form['school']['school_name'] = [
      '#type' => 'textfield',
      '#title' => $this->t('School name'),
      '#default_value' => $institution,
      '#description' => $this->t('Enter the full name of your school (ex. Drupal State University).'),
      '#required' => TRUE,
    ];

    $form['school']['school_short'] = [
      '#type' => 'textfield',
      '#title' => $this->t('School abbreviation'),
      '#default_value' => $settings['school_short'],
      '#size' => 10,
      '#description' => $this->t('Enter an abbreviation of your school name that contains no spaces (ex. DSU, DrupalU).'),
      '#required' => TRUE,
    ];

    $form['school']['tuition'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Tuition amount'),
      '#default_value' => $comma_tuition,
      '#description' => $this->t('Enter the full tuition for your school (ex. $200,000).'),
      '#required' => TRUE,
    ];

    // Calc tab.
    $form['calc_block'] = [
      '#type' => 'details',
      '#title' => $this->t('Calculator Block'),
      '#group' => 'calc',
    ];

    $form['calc_block']['calc_title'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Title text'),
      '#default_value' => $settings['calc_title'],
      '#description' => $this->t('Enter title text for this block.'),
    ];

    $form['calc_block']['calc_intro'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Intro text'),
      '#default_value' => $settings['calc_intro'],
      '#description' => $this->t('Enter descriptive text to be placed at the top of this block.'),
    ];

    $form['calc_block']['calc_label_school'] = [
      '#type' => 'textfield',
      '#title' => $this->t('School row label'),
      '#default_value' => $settings['calc_label_school'],
      '#description' => $this->t('Enter label text for the School row (ex. School Name).'),
      '#required' => TRUE,
    ];

    $form['calc_block']['calc_label_tuition'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Tuition row label'),
      '#default_value' => $settings['calc_label_tuition'],
      '#description' => $this->t('Enter label text for the Tuition row (ex. Tuition).'),
      '#required' => TRUE,
    ];

    $form['calc_block']['calc_label_row_3'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Row three label'),
      '#default_value' => $settings['calc_label_row_3'],
      '#description' => $this->t('Enter label text for the third row (ex. Grants).'),
      '#required' => TRUE,
    ];

    $form['calc_block']['calc_label_row_4'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Row four label'),
      '#default_value' => $settings['calc_label_row_4'],
      '#description' => $this->t('Enter label text for the fourth row (ex. Scholarships).'),
      '#required' => TRUE,
    ];

    $form['calc_block']['calc_label_row_5'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Row five label'),
      '#default_value' => $settings['calc_label_row_5'],
      '#description' => $this->t('Enter label text for the fifth row (ex. Loans).'),
      '#required' => TRUE,
    ];
    $form['calc_block']['calc_disc'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Disclaimer'),
      '#default_value' => $settings['calc_disc'],
      '#description' => $this->t('Enter disclaimer text to be placed at the bottom of this block.'),
    ];

    // Comp tab.
    $form['comp_block'] = [
      '#type' => 'details',
      '#title' => $this->t('Comparison Block'),
      '#group' => 'calc',
    ];

    $form['comp_block']['comp_title'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Title text'),
      '#default_value' => $settings['comp_title'],
      '#description' => $this->t('Enter title text for this block.'),
    ];

    $form['comp_block']['comp_intro'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Intro text'),
      '#default_value' => $settings['comp_intro'],
      '#description' => $this->t('Enter descriptive text to be placed at the top of this block.'),
    ];

    $form['comp_block']['comp_label_school'] = [
      '#type' => 'textfield',
      '#title' => $this->t('School row label'),
      '#default_value' => $settings['comp_label_school'],
      '#description' => $this->t('Enter label text for the School row (ex. School Name).'),
      '#required' => TRUE,
    ];

    $form['comp_block']['comp_label_tuition'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Tuition row label'),
      '#default_value' => $settings['comp_label_tuition'],
      '#description' => $this->t('Enter label text for the Tuition row (ex. Tuition).'),
      '#required' => TRUE,
    ];

    $form['comp_block']['comp_label_row_3'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Row three label'),
      '#default_value' => $settings['comp_label_row_3'],
      '#description' => $this->t('Enter label text for the third row (ex. Grants).'),
      '#required' => TRUE,
    ];

    $form['comp_block']['comp_label_row_4'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Row four label'),
      '#default_value' => $settings['comp_label_row_4'],
      '#description' => $this->t('Enter label text for the fourth row (ex. Scholarships).'),
      '#required' => TRUE,
    ];

    $form['comp_block']['comp_label_row_5'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Row five label'),
      '#default_value' => $settings['comp_label_row_5'],
      '#description' => $this->t('Enter label text for the fifth row (ex. Loans).'),
      '#required' => TRUE,
    ];
    $form['comp_block']['comp_disc'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Disclaimer'),
      '#default_value' => $settings['comp_disc'],
      '#description' => $this->t('Enter disclaimer text to be placed at the bottom of this block.'),
    ];

    $form['calc_bottom'] = [
      '#type' => 'item',
      '#suffix' => '<hr>',
    ];

    // Setting for PDF header.
    $form['pdf_top'] = array(
      '#type' => 'item',
      '#prefix' => '<hr>',
    );
    // Build form elements.
    $form['pdf'] = [
      '#type' => 'vertical_tabs',
      '#attributes' => ['class' => ['tuition-calculator-pdf']],
      '#title' => t('PDF DOWNLOAD SETTINGS'),
      '#description' => t(''),
    ];

    // PDF tab.
    $form['pdf_settings'] = [
      '#type' => 'details',
      '#title' => $this->t('General Settings'),
      '#group' => 'pdf',
    ];

    $form['pdf_settings']['enable_pdf'] = [
      '#type' => 'radios',
      '#title' => t('Enable PDF downloads'),
      '#description' => $this->t('Let users download PDF copies of their calculator results.'),
      '#options' => ['0' => 'No', '1' => 'Yes'],
      '#default_value' => $settings['enable_pdf'],
    ];

    $filename = $settings['pdf_filename'];
    $form['pdf_settings']['pdf_filename'] = [
      '#type' => 'textfield',
      '#disabled' => true,
      '#title' => $this->t('PDF Filename'),
      '#required' => TRUE,
      '#default_value' => isset($filename) && $filename != NULL ? $filename : 'ex. tuition-dsu-YYYY-MM-DD-HH-200000.pdf',
      '#states' => $this->statesArray('enable_pdf'),
    ];

    $form['pdf_settings']['pdf_save_option'] = [
      '#type' => 'radios',
      '#title' => t('Open PDF File in'),
      '#options' => [
        $this->t('Web Browser'),
        $this->t('Save Dialog Box'),
        $this->t('Save to Server')
      ],
      '#default_value' => $settings['pdf_save_option'],
      '#states' => $this->statesArray('enable_pdf'),
    ];

    $form['pdf_settings']['pdf_css_file'] = [
      '#type' => 'managed_file',
      '#title' => t('PDF CSS file'),
      '#description' => t('Upload a CSS file that contains PDF style classes.'),
      '#default_value' => !empty($settings['pdf_css_file']) ? $settings['pdf_css_file'] : [],
      '#upload_location' => 'public://pdf/css/',
      '#upload_validators' => [
        'file_validate_extensions' => ['css'],
        'file_validate_size' => [1024 * 1024],
      ],
      '#states' => $this->statesArray('enable_pdf'),
    ];
    $form['pdf_settings']['pdf_filepath'] = [
      '#type' => 'textfield',
      '#disabled' => true,
      '#title' => t('PDF files directory path'),
      '#default_value' =>  'public://' . $settings['pdf_filepath'] . '/',
      '#states' => $this->statesArray('enable_pdf'),
    ];

    // Document properties.
    $form['pdf_properties'] = [
      '#type' => 'details',
      '#title' => $this->t('Document Properties'),
      '#description' => $this->t('These optional properties can be seen when inspecting the document properties like in Adobe Reader.'),
      '#group' => 'pdf'
    ];
    $form['pdf_properties']['pdf_set_title'] = [
      '#type' => 'textfield',
      '#size' => 35,
      '#title' => $this->t('Title'),
      '#default_value' => $settings['pdf_set_title'],
      '#description' => $this->t('Set the title for the document.'),
    ];
    $form['pdf_properties']['pdf_set_author'] = [
      '#type' => 'textfield',
      '#size' => 35,
      '#title' => $this->t('Author'),
      '#default_value' => $settings['pdf_set_author'],
      '#description' => $this->t('Set the Author for the document.'),
    ];
    $form['pdf_properties']['pdf_set_subject'] = [
      '#type' => 'textfield',
      '#size' => 35,
      '#title' => $this->t('Subject'),
      '#default_value' => $settings['pdf_set_subject'],
      '#description' => $this->t('Set Subject of PDF.'),
    ];
    $form['pdf_properties']['pdf_set_creator'] = [
      '#type' => 'textfield',
      '#size' => 35,
      '#title' => $this->t('Creator'),
      '#default_value' => $settings['pdf_set_creator'],
      '#description' => $this->t('Set the document Creator.'),
    ];

    // Page settings.

    $form['pdf_page_settings'] = [
      '#type' => 'details',
      '#title' => $this->t('Page Settings'),
      '#description' => $this->t('All margin values should be specified as LENGTH in millimetres.'),
      '#group' => 'pdf'
    ];
    $form['pdf_page_settings']['margin_top'] = [
      '#type' => 'textfield',
      '#size' => 5,
      '#title' => $this->t('Top Margin'),
      '#default_value' => $settings['margin_top'],
    ];
    $form['pdf_page_settings']['margin_right'] = [
      '#type' => 'textfield',
      '#size' => 5,
      '#title' => $this->t('Right Margin'),
      '#default_value' => $settings['margin_right'],
    ];
    $form['pdf_page_settings']['margin_bottom'] = [
      '#type' => 'textfield',
      '#size' => 5,
      '#title' => $this->t('Bottom Margin'),
      '#default_value' => $settings['margin_bottom'],
    ];
    $form['pdf_page_settings']['margin_left'] = [
      '#type' => 'textfield',
      '#size' => 5,
      '#title' => $this->t('Left Margin'),
      '#default_value' => $settings['margin_left'],
    ];
    $form['pdf_page_settings']['margin_header'] = [
      '#type' => 'textfield',
      '#size' => 5,
      '#title' => $this->t('Header Margin'),
      '#default_value' => $settings['margin_header'],
    ];
    $form['pdf_page_settings']['margin_footer'] = [
      '#type' => 'textfield',
      '#size' => 5,
      '#title' => $this->t('Footer Margin'),
      '#default_value' => $settings['margin_footer'],
    ];
    $form['pdf_page_settings']['pdf_font_size'] = [
      '#type' => 'textfield',
      '#size' => 5,
      '#title' => $this->t('Font Size'),
      '#default_value' => $settings['pdf_font_size'],
    ];
    $form['pdf_page_settings']['pdf_default_font'] = [
      '#type' => 'select',
      '#title' => $this->t('Default Font Style'),
      '#description' => $this->t('These are the default fonts provided by mPDF. This may not work for HTML content if your styles already have a <em>font-family</em> property.'),
      '#options' => $this->get_default_fonts(),
      '#default_value' => $settings['pdf_default_font'],
    ];
    $form['pdf_page_settings']['pdf_page_size'] = [
      '#type' => 'select',
      '#title' => $this->t('Page Size'),
      '#options' => $this->getPageSizeOptions(),
      '#default_value' => $settings['pdf_page_size'],
    ];
    $form['pdf_page_settings']['dpi'] = [
      '#type' => 'textfield',
      '#size' => 5,
      '#title' => $this->t('Document DPI'),
      '#default_value' => $settings['dpi'],
    ];
    $form['pdf_page_settings']['img_dpi'] = [
      '#type' => 'textfield',
      '#size' => 5,
      '#title' => $this->t('Image DPI'),
      '#default_value' => $settings['img_dpi'],
    ];
    $form['pdf_page_settings']['orientation'] = [
      '#type' => 'select',
      '#title' => $this->t('Orientation'),
      '#default_value' => $settings['orientation'],
      '#options' => [
        'P' => $this->t('Portrait'),
        'L' => $this->t('Landscape'),
      ],
    ];

    // Header.
    $form['pdf_header'] = [
      '#type' => 'details',
      '#title' => t('Header'),
      '#description' => t(''),
      '#group' => 'pdf',
    ];
    $form['pdf_header']['pdf_header_bg_color'] = [
      '#type' => 'textfield',
      '#size' => 10,
      '#title' => t('Header background color'),
      '#description' => t('Enter a hex color to fill in the PDF header with (ex. #FF0000).'),
      '#default_value' => $settings['pdf_header_bg_color'],
    ];
    $form['pdf_header']['pdf_header_image'] = [
      '#type' => 'managed_file',
      '#title' => t('PDF Header Image'),
      '#description' => t('Upload a school logo or other image to display in the PDF header.'),
      '#default_value' => !empty($settings['pdf_header_image']) ? $settings['pdf_header_image'] : [],
      '#upload_location' => 'public://pdf/',
      '#upload_validators' => [
        'file_validate_extensions' => ['gif png jpg jpeg'],
        'file_validate_size' => [1024 * 1024],
      ],
    ];

    $form['pdf_header']['pdf_header'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Header content'),
      '#description' => $this->t('Use a valid HTML code to write a custom header content. Example:') . ' &#60;div&#62;&#60;img src="http://www.example.com/sites/default/files/company_logo.png" width="300px" height="50px" &#62;&#60;/div&#62; &#60;hr /&#62;',
      '#default_value' => $settings['pdf_header'],
    ];

    // Footer.
    $form['tab_foot'] = [
      '#type' => 'details',
      '#title' => $this->t('Footer'),
      '#description' => $this->t('use {PAGENO} for page numbering or {DATE j-m-Y} for current date.'),
      '#group' => 'pdf',
    ];
    $form['tab_foot']['pdf_footer'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Footer content'),
      '#description' => $this->t('Use a valid HTML code to write a custom footer content. Example:') . ' &#60;hr /&#62; &#60;div style="color:#f00; text-align:center;" &#62; &#60;strong&#62;Your Company&#60;/strong&#62;, web: &#60;a href="http://example.com"&#62;www.example.com&#60;/a&#62;, email : contact@example.com&#60;/div&#62;',
      '#default_value' => $settings['pdf_footer'],
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * Returns states array for a form element.
   *
   * @param string $variable
   *   The name of the form element.
   *
   * @return array
   *   The states array.
   */
  public function statesArray($variable) {
    return [
      'visible' => [
        ':input[name="' . $variable . '"]' => ['value' => '1'],
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->getValues();

    $school_short = $form_state->getValues()['school_short'];
    $school_short_clean = preg_replace('/\s+/', '', $school_short);
    $form_state->setValue('school_short', $school_short_clean);

    if (!is_numeric($values['pdf_font_size']) || $values['pdf_font_size'] < 1) {
      $form_state->setErrorByName('pdf_font_size', $this->t('Font size should be numeric and greater than 1.'));
    }
    if (!is_numeric($values['margin_top']) || $values['margin_top'] <= 0) {
      $form_state->setErrorByName('margin_top', $this->t('PDF top margin should be numeric and greater than -1.'));
    }
    if (!is_numeric($values['margin_right']) || $values['margin_right'] <= 0) {
      $form_state->setErrorByName('margin_right', $this->t('PDF right margin should be numeric and greater than -1.'));
    }
    if (!is_numeric($values['margin_bottom']) || $values['margin_bottom'] <= 0) {
      $form_state->setErrorByName('margin_bottom', $this->t('PDF bottom margin should be numeric and greater than -1.'));
    }
    if (!is_numeric($values['margin_left']) || $values['margin_left'] <= 0) {
      $form_state->setErrorByName('margin_left', $this->t('PDF left margin should be numeric and greater than -1.'));
    }
    if (!is_numeric($values['margin_header']) || $values['margin_header'] <= 0) {
      $form_state->setErrorByName('margin_header', $this->t('PDF header margin should be numeric and greater than -1.'));
    }
    if (!is_numeric($values['margin_footer']) || $values['margin_footer'] <= 0) {
      $form_state->setErrorByName('margin_footer', $this->t('PDF footer margin should be numeric and greater than -1.'));
    }
    if (!is_numeric($values['dpi']) || $values['dpi'] < 0) {
      $form_state->setErrorByName('dpi', $this->t('Document DPI should be numeric and greater than 0.'));
    }
    if (!is_numeric($values['img_dpi']) || $values['img_dpi'] < 0) {
      $form_state->setErrorByName('img_dpi', $this->t('Image DPI should be numeric and greater than 0.'));
    }

    // Change css file status to permanent.
    if (!empty($values['pdf_css_file'])) {
      $file = File::load($values['pdf_css_file'][0]);
      if (!$file->isPermanent()) {
        $file->setPermanent();
        $file->save();
        $pdf_css_file_name = $file->getFilename();
        $form_state->setValue('pdf_css_file_name', $pdf_css_file_name);
        $file_usage = \Drupal::service('file.usage');
        $file_usage->add($file, 'tuition_calculator', 'user', \Drupal::currentUser()->id());
      }
    }
    // Change header image status to permanent.
    if (!empty($values['pdf_header_image'])) {
      $file = File::load($values['pdf_header_image'][0]);
      if (!$file->isPermanent()) {
        $file->setPermanent();
        $file->save();
        $pdf_header_image_name = $file->getFilename();
        $form_state->setValue('pdf_css_file_name', $pdf_header_image_name);
        $file_usage = \Drupal::service('file.usage');
        $file_usage->add($file, 'tuition_calculator', 'user', \Drupal::currentUser()->id());
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $pdf_css_file = $form_state->getValue('pdf_css_file');
    $filespath = \Drupal::service('file_system')
        ->realpath(\Drupal::config('system.file')
            ->get('default_scheme') . "://") . '/';
    $filesdir = substr($filespath, strpos($filespath, "/sites/"));
    $pathdir = $filesdir . 'pdf';
    $pdf_css_file_path = $pathdir . '/' . $pdf_css_file;
    $pdf_css_module_path = drupal_get_path('module', 'tuition_calculator') . '/css/tuition-calculator-pdf.css';

    if (file_exists($pdf_css_file_path)) {
      $pdf_css_file = $pdf_css_file_path;
      ;
    }
    else {
      $pdf_css_file = $pdf_css_module_path;
    }

    $strip = ['$', ',', '.'];
    $tuition = (int) str_replace($strip, '', $form_state->getValue('tuition'));
    $pdf_date_now = date('U');
    $pdf_date_string = \Drupal::service('date.formatter')
      ->format($pdf_date_now, 'custom', 'Y-m-d-H-');

    $total_0 = $form_state->getValue('total_0');

    $values = $form_state->getValues();
    $settings = [
      'school_name' => $values['school_name'],
      'school_short' => $values['school_short'],
      'tuition' => $tuition,
      'calc_title' => $values['calc_title'],
      'calc_intro' => $values['calc_intro'],
      'calc_disc' => $values['calc_disc'],
      'calc_label_school' => $values['calc_label_school'],
      'calc_label_tuition' => $values['calc_label_tuition'],
      'calc_label_row_3' => $values['calc_label_row_3'],
      'calc_label_row_4' => $values['calc_label_row_4'],
      'calc_label_row_5' => $values['calc_label_row_5'],
      'comp_title' => $values['comp_title'],
      'comp_intro' => $values['comp_intro'],
      'comp_disc' => $values['comp_disc'],
      'comp_label_school' => $values['comp_label_school'],
      'comp_label_tuition' => $values['comp_label_tuition'],
      'comp_label_row_3' => $values['comp_label_row_3'],
      'comp_label_row_4' => $values['comp_label_row_4'],
      'comp_label_row_5' => $values['comp_label_row_5'],
      'enable_pdf' => $values['enable_pdf'],
      'pdf_filename' => 'tuition-'. $values['school_short'].'-' .$pdf_date_string .'-' . $total_0.'.pdf',
      'pdf_filepath' => 'pdf',
      'pdf_save_option' => $values['pdf_save_option'],
      'pdf_set_title' => $values['pdf_set_title'],
      'pdf_set_author' => $values['pdf_set_author'],
      'pdf_set_subject' => $values['pdf_set_subject'],
      'pdf_set_creator' => $values['pdf_set_creator'],
      'margin_top' => $values['margin_top'],
      'margin_right' => $values['margin_right'],
      'margin_bottom' => $values['margin_bottom'],
      'margin_left' => $values['margin_left'],
      'margin_header' => $values['margin_header'],
      'margin_footer' => $values['margin_footer'],
      'pdf_font_size' => $values['pdf_font_size'],
      'pdf_default_font' => $values['pdf_default_font'],
      'pdf_page_size' => $values['pdf_page_size'],
      'dpi' => $values['dpi'],
      'img_dpi' => $values['img_dpi'],
      'orientation' => $values['orientation'],
      'pdf_header_bg_color' => $values['pdf_header_bg_color'],
      'pdf_header_image' => !empty($values['pdf_header_image']) ? $values['pdf_header_image'] : [],
      'pdf_header' => $values['pdf_header'],
      'pdf_footer' => $values['pdf_footer'],
      'pdf_css_file' => !empty($values['pdf_css_file']) ? $values['pdf_css_file'] : [],
    ];


    // Save the configuration into database.
    $this->configFactory()
      ->getEditable('tuition_calculator.settings')
      ->set('tuition_calculator', $settings)
      ->save();

    parent::submitForm($form, $form_state);
  }

  /**
   * Get default font styles provided by mPDF library.
   *
   * @return array
   */
  public function get_default_fonts() {
    return [
      'dejavusanscondensed' => 'DejaVuSansCondensed',
      'dejavusans' => 'DejaVuSans',
      'dejavuserif' => 'DejaVuSerif',
      'dejavuserifcondensed' => 'DejaVuSerifCondensed',
      'dejavusansmono' => 'DejaVuSansMono',
      'freesans' => 'FreeSans',
      'freeserif' => 'FreeSerif',
      'freemono' => 'FreeMono',
      'ocrb' => 'ocrb10',
      'estrangeloedessa' => 'SyrCOMEdessa',
      'kaputaunicode' => 'kaputaunicode',
      'abyssinicasil' => 'Abyssinica_SIL',
      'aboriginalsans' => 'AboriginalSansREGULAR',
      'jomolhari' => 'Jomolhari',
      'sundaneseunicode' => 'SundaneseUnicode-1.0.5',
      'taiheritagepro' => 'TaiHeritagePro',
      'aegean' => 'Aegean',
      'aegyptus' => 'Aegyptus',
      'akkadian' => 'Akkadian',
      'quivira' => 'Quivira',
      'eeyekunicode' => 'Eeyek',
      'lannaalif' => 'lannaalif-v1-03',
      'daibannasilbook' => 'DBSILBR',
      'garuda' => 'Garuda',
      'khmeros' => 'KhmerOS',
      'dhyana' => 'Dhyana',
      'tharlon' => 'Tharlon',
      'padaukbook' => 'Padauk-book',
      'zawgyi-one' => 'ZawgyiOne',
      'ayar' => 'ayar',
      'taameydavidclm' => 'TaameyDavidCLM',
      'mph2bdamase' => 'damase_v.2',
      'lohitkannada' => 'Lohit-Kannada',
      'pothana2000' => 'Pothana2000',
      'xbriyaz' => 'XB Riyaz',
      'lateef' => 'LateefRegOT',
      'kfgqpcuthmantahanaskh' => 'Uthman',
      'sun-exta' => 'Sun-ExtA',
      'sun-extb' => 'Sun-ExtB',
      'unbatang' => 'UnBatang_0613',
    ];
  }

  /**
   * International Paper Sizes.
   *
   * @return array
   */
  public function getPageSizeOptions() {
    return [
      'A0' => 'A0',
      'A1' => 'A1',
      'A2' => 'A2',
      'A3' => 'A3',
      'A4' => 'A4',
      'A5' => 'A5',
      'A6' => 'A6',
      'A7' => 'A7',
      'A8' => 'A8',
      'A9' => 'A9',
      'A10' => 'A10',
      'B0' => 'B0',
      'B1' => 'B1',
      'B2' => 'B2',
      'B3' => 'B3',
      'B4' => 'B4',
      'B5' => 'B5',
      'B6' => 'B6',
      'B7' => 'B7',
      'B8' => 'B8',
      'B9' => 'B9',
      'B10' => 'B10',
      'C0' => 'C0',
      'C1' => 'C1',
      'C2' => 'C2',
      'C3' => 'C3',
      'C4' => 'C4',
      'C5' => 'C5',
      'C6' => 'C6',
      'C7' => 'C7',
      'C8' => 'C8',
      'C9' => 'C9',
      'C10' => 'C10',
      '2A0' => '2A0',
      '4A0' => '4A0',
      'RA0' => 'RA0',
      'RA1' => 'RA1',
      'RA2' => 'RA2',
      'RA3' => 'RA3',
      'SRA0' => 'SRA0',
      'SRA1' => 'SRA1',
      'SRA2' => 'SRA2',
      'SRA3' => 'SRA3',
      'SRA4' => 'SRA4',
      'Letter' => 'Letter',
      'Legal' => 'Legal',
    ];
  }

}
